@@ -8,7 +8,7 @@ from functools import partial
 import logging
 import subprocess
 import tempfile
-from multiprocessing.pool import Pool
+# from multiprocessing.pool import Pool
 from decorator import decorator
 from .errors import ClientScriptError
 from .utils import NullHandler, renderdump_temp, fitargspec
@@ -16,6 +16,7 @@ from .render import (RenderClient, renderaccess, Render,
                      format_preamble, format_baseurl)
 from .stack import set_stack_state, make_stack_params
 from .resolvedtiles import put_tilespecs
+from renderapi.external.processpools.stdlib_pool import WithMultiprocessingPool
 
 # setup logger
 logger = logging.getLogger(__name__)
@@ -78,32 +79,33 @@ def renderclientaccess(f, *args, **kwargs):
     return f(*args, **kwargs)
 
 
-class WithPool(Pool):
-    """Multiprocessing.pool.Pool with functioning __exit__ call
-
-    Parameters
-    ----------
-    *args
-        variable length argument list matching input
-        to multiprocessing.pool.Pool
-    **kwargs
-        keyword argument input matching multiprocessing.pool.Pool
-
-    Examples
-    --------
-    >>> with WithPool(number_processes) as pool:
-    >>>     pool.map(myfunc, myInput)
-    """
-
-    def __init__(self, *args, **kwargs):
-        super(WithPool, self).__init__(*args, **kwargs)
-
-    def __enter__(self):
-        return self
-
-    def __exit__(self, *args, **kwargs):
-        self.close()
-        self.join()
+WithPool = WithMultiprocessingPool
+# class WithPool(Pool):
+#     """Multiprocessing.pool.Pool with functioning __exit__ call
+#
+#     Parameters
+#     ----------
+#     *args
+#         variable length argument list matching input
+#         to multiprocessing.pool.Pool
+#     **kwargs
+#         keyword argument input matching multiprocessing.pool.Pool
+#
+#     Examples
+#     --------
+#     >>> with WithPool(number_processes) as pool:
+#     >>>     pool.map(myfunc, myInput)
+#     """
+#
+#     def __init__(self, *args, **kwargs):
+#         super(WithPool, self).__init__(*args, **kwargs)
+#
+#     def __enter__(self):
+#         return self
+#
+#     def __exit__(self, *args, **kwargs):
+#         self.close()
+#         self.join()
 
 
 @renderclientaccess
@@ -1040,6 +1042,7 @@ class SiftPointMatchOptions(MatchDerivationParameters,
 
 @renderclientaccess
 def pointMatchClient(stack, collection, tile_pairs,
+                     stack2 = None,
                      sift_options=None,
                      pointMatchRender=None,
                      debugDirectory=None,
@@ -1058,6 +1061,8 @@ def pointMatchClient(stack, collection, tile_pairs,
     ----------
     stack : str
         stack containing the tiles
+    stack2 : str
+        second optional stack containing tiles (if stack2 is not none, then tile_pair['p'] comes from stack and tile_pair['q'] comes from stack2)
     collection : str
         point match collection to save results into
     tile_pairs : iterable
@@ -1126,9 +1131,26 @@ def pointMatchClient(stack, collection, tile_pairs,
         project=project,
         client_script=client_script)
 
+    if stack2 is not None:
+        canvas_url_template2 = get_canvas_url_template(
+            stack2,
+            filter,
+            renderWithoutMask,
+            normalizeForMatching,
+            excludeTransformsAfterLast,
+            excludeFirstTransformAndAllAfter,
+            excludeAllTransforms,
+            host=host,
+            port=port,
+            owner=owner,
+            project=project,
+            client_script=client_script)
+    else:
+        canvas_url_template2 = canvas_url_template
+
     for tile1, tile2 in tile_pairs:
         argvs += [canvas_url_template.format(tile1),
-                  canvas_url_template.format(tile2)]
+                  canvas_url_template2.format(tile2)]
 
     call_run_ws_client('org.janelia.render.client.PointMatchClient',
                        memGB=memGB, client_script=client_script,
